﻿<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <xsl:output method="html"/>

  <xsl:param name="pageheight">200</xsl:param>
  <xsl:param name="pagewidth">400</xsl:param>

  <xsl:include href="shared_templates.xsl"/>

  <!-- the main template -->
  <xsl:template match="/">
    <HTML>
      <HEAD>
        <LINK REL="StyleSheet" TYPE="text/css" HREF="print_item_details.css"></LINK>
        <META http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
        <TITLE>Movie</TITLE>
      </HEAD>
      <BODY marginheight="0" marginwidth="0" leftmargin="0" rightmargin="0" topmargin="0" bottommargin="0" border="0" class="bodybg">
        <xsl:apply-templates/>
      </BODY>
    </HTML>
  </xsl:template>

  <xsl:template match="movieInfo">
    <table border="0" cellspacing="0" cellpadding="0" width="100%" class="maintable">
      <tr>
        <td>
          <table border="0" cellspacing="1" cellpadding="0" width="100%">
            <tr>
              <td class="maintitle" width="100%">
                <xsl:value-of select="title"/>
                <xsl:if test="year!=''">
                  <xsl:text> (</xsl:text><xsl:value-of select="year"/>)
                </xsl:if>
              </td>
            </tr>
          </table>
          <xsl:if test="tagline!=''">
            <table border="0" cellspacing="1" cellpadding="0" width="100%">
              <tr>
                <td class="tagtitle" width="100%">
                  <xsl:value-of select="tagline"/>
                </td>
              </tr>
            </table>
          </xsl:if>
          <table border="0" cellspacing="1" cellpadding="0" width="100%">
            <tr>
              <xsl:if test="picture!=''">
                <td class="subtitle" height="17">
                  <xsl:value-of select="/movies/metadata/field[@name='picture']/@label"/>
                </td>
              </xsl:if>
              <td class="subtitle" height="17" align="left">
                <xsl:if test="actors!=''">
                  <xsl:value-of select="/movies/metadata/field[@name='actors']/@label"/>
                </xsl:if>
              </td>
            </tr>
            <tr valign="top">
              <xsl:if test="picture!=''">
                <td width="1" class="detailsbg">
                  <img src="{picture}" border="0" height="200"/>
                </td>
              </xsl:if>
              <td class="detailsbg" valign="top">
                <xsl:if test="actors!=''">
                  <table border="0" cellspacing="1" cellpadding="0" width="100%" height="100%">
                    <xsl:for-each select="actors/actor">
                      <tr>
                        <td class="cellvalue" nowrap="1">
                          <xsl:value-of select="node()" />
                        </td>
                      </tr>
                    </xsl:for-each>
                  </table>
                </xsl:if>
              </td>
            </tr>
          </table>
          <table border="0" cellspacing="1" cellpadding="0" width="100%">
            <tr>
              <td valign="top" class="detailsbg">
                <table width="100%" height="100%" border="0" cellspacing="1" cellpadding="0">
                  <tr>
                    <td class="subtitle" height="17" align="left" colspan="2">
                      <xsl:value-of select="/movies/metadata/field[@name='movieInfo']/@label"/>
                    </td>
                  </tr>
                  <xsl:if test="genres!=''">
                    <tr valign="top">
                      <td width="10%" nowrap="1" class="celllabel">
                        <xsl:value-of select="/movies/metadata/field[@name='genres']/@label"/>
                      </td>
                      <td class="cellvalue">
                        <xsl:for-each select="genres/genre">
                          <xsl:value-of select="node()"/>
                          <xsl:if test="position()!=last()">
                            <xsl:text>; </xsl:text>
                          </xsl:if>
                        </xsl:for-each>
                      </td>
                    </tr>
                  </xsl:if>
                  <xsl:if test="director!=''">
                    <tr valign="top">
                      <td class="celllabel" width="10%" nowrap="1">
                        <xsl:value-of select="/movies/metadata/field[@name='director']/@label"/>
                      </td>
                      <td class="cellvalue">
                        <xsl:value-of select="director"/>
                      </td>
                    </tr>
                  </xsl:if>
                  <xsl:if test="writer!=''">
                    <tr valign="top">
                      <td class="celllabel" width="10%" nowrap="1">
                        <xsl:value-of select="/movies/metadata/field[@name='writer']/@label"/>
                      </td>
                      <td class="cellvalue">
                        <xsl:value-of select="director"/>
                      </td>
                    </tr>
                  </xsl:if>
                  <xsl:if test="runtime!=''">
                    <tr valign="top">
                      <td class="celllabel" width="10%" nowrap="1">
                        <xsl:value-of select="/movies/metadata/field[@name='runtime']/@label"/>
                      </td>
                      <td class="cellvalue">
                        <xsl:value-of select="runtime"/>
                      </td>
                    </tr>
                  </xsl:if>
                  <xsl:if test="mpaaRating!='' and mpaaRating!='unknown'">
                    <tr valign="top">
                      <td class="celllabel" width="10%" nowrap="1">
                        <xsl:value-of select="/movies/metadata/field[@name='mpaaRating']/@label"/>
                      </td>
                      <td class="cellvalue">
                        <xsl:value-of select="mpaaRating"/>
                      </td>
                    </tr>
                  </xsl:if>
                  <xsl:if test="imdbRating!=''">
                    <tr valign="top">
                      <td class="celllabel" width="10%" nowrap="1">
                        <xsl:value-of select="/movies/metadata/field[@name='imdbRating']/@label"/>
                      </td>
                      <td class="cellvalue">
                        <xsl:value-of select="imdbRating"/>
                      </td>
                    </tr>
                  </xsl:if>
                </table>
              </td>
            </tr>
          </table>
          <xsl:if test="description!=''">
            <table border="0" cellspacing="1" cellpadding="0" width="100%">
              <tr>
                <td class="subtitle" height="17" align="left">
                  <xsl:value-of select="/movies/metadata/field[@name='description']/@label"/>
                </td>
              </tr>
              <tr>
                <td class="cellalt">
                  <xsl:call-template name="break">
                    <xsl:with-param name="text" select="description"/>
                  </xsl:call-template>
                </td>
              </tr>
            </table>
          </xsl:if>
        </td>
      </tr>
    </table>
    <xsl:if test="position()!=last()">
      <p style="page-break-before: always"/>
    </xsl:if>
  </xsl:template>
</xsl:stylesheet>