﻿<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <xsl:variable name="nrOfActors">10</xsl:variable>

  <xsl:output method="html"/>

  <xsl:param name="pageheight">200</xsl:param>
  <xsl:param name="pagewidth">400</xsl:param>

  <xsl:include href="shared_templates.xsl"/>

  <!-- the main template -->
  <xsl:template match="/">
    <HTML>
      <HEAD>
        <LINK REL="StyleSheet" TYPE="text/css" HREF="view_item_details_aqua2.css"></LINK>
        <META http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
        <TITLE>Movie</TITLE>
      </HEAD>
      <BODY marginheight="0" marginwidth="0" leftmargin="5" rightmargin="5" topmargin="3" bottommargin="5" border="0" class="bodybg">
        <xsl:apply-templates/>
      </BODY>
    </HTML>
  </xsl:template>

  <xsl:template match="movieInfo">
    <table border="0" cellspacing="0" cellpadding="0" width="100%" class="maintable">
      <tr>
        <td>
          <table border="0" cellspacing="1" cellpadding="0" width="100%">
            <tr>
              <td class="maintitle" width="100%">
                <xsl:value-of select="title"/>
                <xsl:if test="year!=''">
                  <xsl:text> (</xsl:text><xsl:value-of select="year"/>)
                </xsl:if>
              </td>
              <xsl:choose>
                <xsl:when test="mediaInfo/video/videoStream/width='1280'">
                  <td class="maintitle" width="100%" aligment="center">
                    <img src="images/Media/720p.png" border="0"/>
                  </td>
                </xsl:when>
                <xsl:when test="mediaInfo/video/videoStream/width='1920'">
                  <td class="maintitle" width="100%" aligment="center">
                    <img src="images/Media/1080p.png" border="0"/>
                  </td>
                </xsl:when>
              </xsl:choose>
            </tr>
          </table>

          <xsl:if test="tagline!=''">
            <table border="0" cellspacing="1" cellpadding="0" width="100%">
              <tr>
                <td class="tagtitle" width="100%">
                  <xsl:value-of select="tagline"/>
                </td>
              </tr>
            </table>
          </xsl:if>

          <!-- IMDB Rating -->
          <table border="0" cellspacing="1" cellpadding="0" width="100%">
            <xsl:if test="imdbRating!=''">
              <tr valign="center">
                <td class="cellalt1" nowrap="1" width="5%">
                  <xsl:value-of select="/movieInfo/metadata/field[@name='imdbRating']/@label"/>
                </td>
                <td class="stars" width="10%" nowrap="1">
                  <xsl:choose>
                    <xsl:when test="contains(imdbRating,' ')">
                      <xsl:call-template name="starIMDB">
                        <xsl:with-param name="numIMDB" select="substring-before(imdbRating,' ')"/>
                      </xsl:call-template>
                    </xsl:when>
                    <xsl:otherwise>
                      <xsl:call-template name="starIMDB">
                        <xsl:with-param name="numIMDB" select="imdbRating"/>
                      </xsl:call-template>
                    </xsl:otherwise>
                  </xsl:choose>
                </td>
                <td class="cellalt1" width="25%">
                  <xsl:value-of select="imdbRating"/>
                </td>
              </tr>
            </xsl:if>
          </table>

          <table border="0" cellspacing="1" cellpadding="0" width="100%">
            <tr>
              <xsl:if test="picture!=''">
                <td class="subtitle" height="17">
                  <xsl:value-of select="/movieInfo/metadata/field[@name='picture']/@label"/>
                </td>
              </xsl:if>
              <td class="subtitle" height="17" align="left">
                <xsl:value-of select="/movieInfo/metadata/field[@name='actors']/@label"/>
              </td>
            </tr>
            <tr valign="top">
              <xsl:if test="picture!=''">
                <td width="1" class="detailsbg">
                  <img src="{picture}" border="0" height="200"/>
                </td>
              </xsl:if>
              <td class="detailsbg" valign="top">
                <xsl:if test="actors!=''">
                  <table border="0" cellspacing="0" cellpadding="0" width="100%">
                    <tr valign="top">
                      <td>
                        <table border="0" cellspacing="1" cellpadding="0" width="100%">
                          <xsl:for-each select="actors/actor[position() &lt;= $nrOfActors]">
                            <tr>
                              <td class="cellvalue" width="10%" nowrap="1">
                                <xsl:value-of select="node()" />
                              </td>
                            </tr>
                          </xsl:for-each>
                        </table>
                      </td>
                    </tr>
                  </table>
                </xsl:if>
              </td>
            </tr>
          </table>

          <xsl:if test="description!=''">
            <table border="0" cellspacing="1" cellpadding="0" width="100%">
              <tr>
                <td class="subtitle" height="17" align="left">
                  <xsl:value-of select="/movieInfo/metadata/field[@name='description']/@label"/>
                </td>
              </tr>
              <tr>
                <td class="plot" colspan="2">
                  <xsl:call-template name="break">
                    <xsl:with-param name="text" select="description"/>
                  </xsl:call-template>
                </td>
              </tr>
            </table>
          </xsl:if>

          <table border="0" cellspacing="1" cellpadding="0" width="100%">
            <tr>
              <td valign="top" class="detailsbg" width="50%">
                <table border="0" cellspacing="1" cellpadding="0" width="100%">
                  <tr>
                    <td class="subtitle" height="17" align="left" colspan="2">
                      <xsl:value-of select="/movieInfo/metadata/field[@name='movieInfo']/@label"/>
                    </td>
                  </tr>
                  <xsl:if test="genres!=''">
                    <tr valign="top">
                      <td width="10%" nowrap="1" class="celllabel">
                        <xsl:value-of select="/movieInfo/metadata/field[@name='genres']/@label"/>
                      </td>
                      <td class="cellvalue">
                        <xsl:for-each select="genres/genre">
                          <xsl:value-of select="node()" />
                          <xsl:if test="position()!=last()">
                            <xsl:text>; </xsl:text>
                          </xsl:if>
                        </xsl:for-each>
                      </td>
                    </tr>
                  </xsl:if>
                  <xsl:if test="director!=''">
                    <tr valign="top">
                      <td width="10%" nowrap="1" class="celllabel">
                        <xsl:value-of select="/movieInfo/metadata/field[@name='director']/@label"/>
                      </td>
                      <td class="cellvalue">
                        <xsl:value-of select="director"/>
                      </td>
                    </tr>
                  </xsl:if>
                  <xsl:if test="writer!=''">
                    <tr valign="top">
                      <td width="10%" nowrap="1" class="celllabel">
                        <xsl:value-of select="/movieInfo/metadata/field[@name='writer']/@label"/>
                      </td>
                      <td class="cellvalue">
                        <xsl:apply-templates select="writer"/>
                      </td>
                    </tr>
                  </xsl:if>
                  <xsl:if test="mpaaRating!=''">
                    <tr valign="top">
                      <td class="celllabel" width="10%" nowrap="1">
                        <xsl:value-of select="/movieInfo/metadata/field[@name='mpaaRating']/@label"/>
                      </td>
                      <td class="cellvalue">
                        <xsl:value-of select="mpaaRating"/>
                      </td>
                    </tr>
                  </xsl:if>
                  <xsl:if test="runtime!=''">
                    <tr valign="top">
                      <td class="celllabel" width="10%" nowrap="1">
                        <xsl:value-of select="/movieInfo/metadata/field[@name='runtime']/@label"/>
                      </td>
                      <td class="cellvalue">
                        <xsl:value-of select="runtime"/>
                        <xsl:text> </xsl:text>
                        <xsl:value-of select="/movieInfo/metadata/field[@name='runtimeUnit']/@label"/>
                      </td>
                    </tr>
                  </xsl:if>
                  <xsl:if test="discId!=''">
                    <tr valign="top">
                      <td class="celllabel" width="10%" nowrap="1">
                        <xsl:value-of select="/movieInfo/metadata/field[@name='discId']/@label"/>
                      </td>
                      <td class="cellvalue">
                        <xsl:value-of select="discId"/>
                      </td>
                    </tr>
                  </xsl:if>

                </table>
              </td>
            </tr>
          </table>

          <xsl:if test="mediaInfo!=''">
            <table border="0" cellspacing="1" cellpadding="0" width="100%">
              <tr>
                <td valign="top" class="detailsbg" width="50%">
                  <table border="0" cellspacing="1" cellpadding="0" width="100%">
                    <tr>
                      <td class="subtitle" height="17" align="left" colspan="2">
                        MediaInfo
                      </td>
                    </tr>
                    <xsl:for-each select="mediaInfo/video/videoStream">
                      <tr valign="top">
                        <td width="10%" nowrap="1" class="celllabel">
                          Video
                          <xsl:if test="last()!=1">
                            <xsl:text> </xsl:text>
                            <xsl:number value="position()"/>
                          </xsl:if>
                        </td>
                        <td class="cellvalue">
                            <xsl:choose>
                              <xsl:when test="codec='V_MPEG4/ISO/AVC'">
                                <xsl:text>H.264, </xsl:text>
                              </xsl:when>
                              <xsl:otherwise>
                                <xsl:choose>
                                  <xsl:when test="codecHint!=''">
                                    <xsl:value-of select="codecHint" />
                                    <xsl:text>, </xsl:text>
                                  </xsl:when>
                                  <xsl:when test="format!=''">
                                    <xsl:value-of select="format" />
                                    <xsl:text>, </xsl:text>
                                  </xsl:when>
                                  <xsl:when test="codec!=''">
                                    <xsl:value-of select="codec" />
                                    <xsl:text>, </xsl:text>
                                  </xsl:when>
                                </xsl:choose>
                              </xsl:otherwise>
                            </xsl:choose>
                            <xsl:value-of select="width" />
                            <xsl:text>x</xsl:text>
                            <xsl:value-of select="height" />
                            <xsl:text> (</xsl:text>
                            <xsl:value-of select="displayAspectRatioStr" />
                            <xsl:text>), </xsl:text>
                            <xsl:text>~</xsl:text>
                            <xsl:value-of select="round(number(bitRate) div 1000)" />
                            <xsl:text> kbps, </xsl:text>
                            <xsl:value-of select="frameRate" />
                            <xsl:text> fps</xsl:text>
                            <xsl:if test="position()!=last()">
                              <br/>
                            </xsl:if>
                        </td>
                      </tr>
                    </xsl:for-each>
                    <xsl:for-each select="mediaInfo/audio/audioStream">
                      <tr valign="top">
                        <td width="10%" nowrap="1" class="celllabel">
                        Audio
                        <xsl:if test="last()!=1">
                          <xsl:text> </xsl:text>
                          <xsl:number value="position()"/>
                        </xsl:if>
                        </td>
                        <td class="cellvalue">
                          <xsl:if test="languageStr!=''">
                            <xsl:value-of select="languageStr" />
                            <xsl:text>, </xsl:text>
                          </xsl:if>

                        <!--xsl:value-of select="format" />
                          <xsl:text>, </xsl:text>
                          <xsl:value-of select="codec" />
                          <xsl:text>, </xsl:text>
                          <xsl:value-of select="codecHint" />
                          <xsl:text>, </xsl:text-->

                          <xsl:choose>                           
                            <xsl:when test="codec='A_AC3'">
                              <!--img src="images/Media/AC3.png" width="60" border="0"/-->
                              <!--img src="images/Media/dolbydigital.gif" border="0"/-->
                              <xsl:text>Dolby Digital, </xsl:text>                           
                            </xsl:when>
                            <!--xsl:when test="codecHint='MP3'">
                              <img src="images/Media/MP3.png" width="60" border="0"/>
                              <img src="images/Media/mp3.gif" border="0"/>
                            </xsl:when-->
                            <xsl:otherwise>
                              <xsl:choose>
                                <xsl:when test="codecHint!=''">
                                  <xsl:value-of select="codecHint" />
                                  <xsl:text>, </xsl:text>
                                </xsl:when>
                                <xsl:when test="format!=''">
                                  <xsl:value-of select="format" />
                                  <xsl:text>, </xsl:text>
                                </xsl:when>
                                <xsl:when test="codec!=''">
                                  <xsl:value-of select="codec" />
                                  <xsl:text>, </xsl:text>
                                </xsl:when>
                              </xsl:choose>
                            </xsl:otherwise>
                          </xsl:choose>
                          <xsl:choose>
                            <xsl:when test="channel='2'">
                              <xsl:text>2.0, </xsl:text>
                            </xsl:when>
                            <xsl:when test="channel='6'">
                              <xsl:text>5.1, </xsl:text>
                            </xsl:when>
                            <xsl:otherwise>
                              <xsl:value-of select="channel" />
                              <xsl:text> ch,</xsl:text>
                            </xsl:otherwise>
                          </xsl:choose>
                          <xsl:value-of select="number(samplingRate) div 1000" />
                          <xsl:text> kHz</xsl:text>
                          <xsl:text>, </xsl:text>
                          <xsl:value-of select="round(number(bitRate) div 1000)" />
                          <xsl:text> kbps</xsl:text>
                          <xsl:if test="position()!=last()">
                            <br/>
                          </xsl:if>
                        </td>
                      </tr>
                    </xsl:for-each>
                  </table>
                </td>
              </tr>
            </table>
          </xsl:if>

        </td>
      </tr>
    </table>
  </xsl:template>
</xsl:stylesheet>